:tocdepth: 2

==================
Reservation API v1
==================

This is a reference for the OpenStack Reservation API which is provided by the
Blazar project.

.. include:: leases.inc
.. include:: hosts.inc
.. include:: floatingips.inc
.. include:: request-ids.inc
.. include:: global-request-id.inc
